==> cramr_ui_lib-1.0.11.tar.gz: test/routes/verb_indicative_evaluate_route_test.dart <==
import 'dart:convert';

import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/streak_engine.dart';
import 'package:cramr_ui_lib/model/verb.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_evaluate_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/util/cardinality_filter.dart';
import 'package:cramr_ui_lib/widgets/evalutation_row.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  test('Test Key generator for wrong answers', () {
    const Key expectedKey = Key('wrong_exp1_1');
    expect(EvaluationRow.wrongAnswerKey('exp1', 1), expectedKey);
  });

  testWidgets('Test the content of a 6/6 score', (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    MaterialApp app = await createMaterialApp(prefs);
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(providers: [
      ChangeNotifierProvider(
        create: (BuildContext context) {
          return initFullModel(false);
        },
      ),
      Provider<AdsController?>(
        create: (BuildContext context) {
          return adsController;
        },
      )
    ], child: app));
    testMetaDataCard();
    testTitle();
    testScore(6, 6);
    for (var element in _randomIndicative) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 3/3 score (singular)',
      (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    List<String> filteredIndicativeList =
        await initScreenForCardinality(tester, prefs, true, false);
    testTitle();
    testScore(filteredIndicativeList.length, filteredIndicativeList.length);
    for (var element in filteredIndicativeList) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 3/3 score (plural)',
      (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    List<String> filteredIndicativeList =
        await initScreenForCardinality(tester, prefs, true, false);
    testMetaDataCard();
    testTitle();
    testScore(filteredIndicativeList.length, filteredIndicativeList.length);
    for (var element in filteredIndicativeList) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 5/6 score', (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    MaterialApp app = await createMaterialApp(prefs);
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(
      providers: [
        ChangeNotifierProvider(
          create: (BuildContext context) {
            return initFullModel(true);
          },
        ),
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ],
      child: app,
    ));
    testMetaDataCard();
    testTitle();
    testScore(5, 6);
    int i = 0;
    for (var element in _randomIndicative) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, i == 2 ? findsNothing : findsOneWidget);
      i++;
    }
    Finder wrongAnswerKeyFinder =
        find.byKey(EvaluationRow.wrongAnswerKey(_randomIndicative[2], 2));
    expect(wrongAnswerKeyFinder, findsOneWidget);
  });
}

Future<List<String>> initScreenForCardinality(
    WidgetTester tester,
    SharedPreferences prefs,
    bool isSingularEnabled,
    bool isPluralEnabled) async {
  var selection = CardinalitySelection(isSingularEnabled, isPluralEnabled);
  var filteredPronounList =
      CardinalityFilter.filteredList(selection, _randomPronouns);
  var filteredIndicativeList =
      CardinalityFilter.filteredList(selection, _randomIndicative);
  MaterialApp app = await createMaterialApp(prefs);
  AdsController? adsController = AdsController(MobileAds.instance);
  await tester.pumpWidget(MultiProvider(providers: [
    ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(filteredIndicativeList, filteredPronounList,
            _randomInfinitive, 'fr', 'translation', _mode, _tense);
        int i = 0;
        for (var element in filteredIndicativeList) {
          model.add(element, i++);
        }
        return model;
      },
    ),
    Provider<AdsController?>(
      create: (BuildContext context) {
        return adsController;
      },
    )
  ], child: app));
  return filteredIndicativeList;
}

Future<SharedPreferences> initPrefs() async {
  StreakEngine engine = StreakEngine();
  engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
      _randomIndicative, StudyMethod.coverMethod));
  engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
      _randomIndicative, StudyMethod.coverMethod));
  SharedPreferences.setMockInitialValues(
      <String, Object>{'counter': 1, 'streakEngine': jsonEncode(engine)});
  SharedPreferences prefs = await SharedPreferences.getInstance();
  return prefs;
}

VerbTestModel<Verb> initFullModel(bool hasMistake) {
  var model = VerbTestModel();
  model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive, 'fr',
      'translation', _mode, _tense);
  int i = 0;
  for (var element in _randomIndicative) {
    model.add(element, i++);
  }
  if (hasMistake) {
    //tamper with 3rd person singular
    model.add('wrong', 2);
  }
  return model;
}

Future<MaterialApp> createMaterialApp(SharedPreferences prefs) async {
  SettingsController controller =
      SettingsController(SettingsService(prefs), ThemeMode.dark, prefs);
  await controller.loadSettings();
  return MaterialApp(
    home: VerbIndicativeEvaluateRoute(controller),
  );
}

void testScore(int achievedScore, int maxScore) {
  Finder scoreFinder = find.text('$achievedScore/$maxScore');
  expect(scoreFinder, findsOneWidget);
}

void testTitle() {
  Finder titleFinderOne = find.text('Rapport');
  expect(titleFinderOne, findsOneWidget);
}

void testMetaDataCard() {
  Finder infinitiveFinder = find.text('werkwoord');
  expect(infinitiveFinder, findsOneWidget);
  Finder translationFinder = find.text('vertaling');
  expect(translationFinder, findsOneWidget);
  Finder modeFinder = find.text('modus');
  expect(modeFinder, findsOneWidget);
  Finder tenseFinder = find.text('tijd');
  expect(tenseFinder, findsOneWidget);
}

==> cramr_ui_lib-1.0.13.tar.gz: test/routes/verb_indicative_evaluate_route_test.dart <==
import 'dart:convert';

import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/streak_engine.dart';
import 'package:cramr_ui_lib/model/verb.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_evaluate_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/util/cardinality_filter.dart';
import 'package:cramr_ui_lib/widgets/evalutation_row.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  test('Test Key generator for wrong answers', () {
    const Key expectedKey = Key('wrong_exp1_1');
    expect(EvaluationRow.wrongAnswerKey('exp1', 1), expectedKey);
  });

  testWidgets('Test the content of a 6/6 score', (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    MaterialApp app = await createMaterialApp(prefs);
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(providers: [
      ChangeNotifierProvider(
        create: (BuildContext context) {
          return initFullModel(false);
        },
      ),
      Provider<AdsController?>(
        create: (BuildContext context) {
          return adsController;
        },
      )
    ], child: app));
    testMetaDataCard();
    testTitle();
    testScore(6, 6);
    for (var element in _randomIndicative) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 3/3 score (singular)',
      (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    List<String> filteredIndicativeList =
        await initScreenForCardinality(tester, prefs, true, false);
    testTitle();
    testScore(filteredIndicativeList.length, filteredIndicativeList.length);
    for (var element in filteredIndicativeList) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 3/3 score (plural)',
      (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    List<String> filteredIndicativeList =
        await initScreenForCardinality(tester, prefs, true, false);
    testMetaDataCard();
    testTitle();
    testScore(filteredIndicativeList.length, filteredIndicativeList.length);
    for (var element in filteredIndicativeList) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    }
  });

  testWidgets('Test the content of a 5/6 score', (WidgetTester tester) async {
    SharedPreferences prefs = await initPrefs();
    MaterialApp app = await createMaterialApp(prefs);
    AdsController? adsController = AdsController(MobileAds.instance);
    await tester.pumpWidget(MultiProvider(
      providers: [
        ChangeNotifierProvider(
          create: (BuildContext context) {
            return initFullModel(true);
          },
        ),
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ],
      child: app,
    ));
    testMetaDataCard();
    testTitle();
    testScore(5, 6);
    int i = 0;
    for (var element in _randomIndicative) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, i == 2 ? findsNothing : findsOneWidget);
      i++;
    }
    Finder wrongAnswerKeyFinder =
        find.byKey(EvaluationRow.wrongAnswerKey(_randomIndicative[2], 2));
    expect(wrongAnswerKeyFinder, findsOneWidget);
  });
}

Future<List<String>> initScreenForCardinality(
    WidgetTester tester,
    SharedPreferences prefs,
    bool isSingularEnabled,
    bool isPluralEnabled) async {
  var selection = CardinalitySelection(isSingularEnabled, isPluralEnabled);
  var filteredPronounList =
      CardinalityFilter.filteredList(selection, _randomPronouns);
  var filteredIndicativeList =
      CardinalityFilter.filteredList(selection, _randomIndicative);
  MaterialApp app = await createMaterialApp(prefs);
  AdsController? adsController = AdsController(MobileAds.instance);
  await tester.pumpWidget(MultiProvider(providers: [
    ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(filteredIndicativeList, filteredPronounList,
            _randomInfinitive, 'fr', 'translation', _mode, _tense);
        int i = 0;
        for (var element in filteredIndicativeList) {
          model.add(element, i++);
        }
        return model;
      },
    ),
    Provider<AdsController?>(
      create: (BuildContext context) {
        return adsController;
      },
    )
  ], child: app));
  return filteredIndicativeList;
}

Future<SharedPreferences> initPrefs() async {
  StreakEngine engine = StreakEngine();
  engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
      _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
  engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
      _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
  SharedPreferences.setMockInitialValues(
      <String, Object>{'counter': 1, 'streakEngine': jsonEncode(engine)});
  SharedPreferences prefs = await SharedPreferences.getInstance();
  return prefs;
}

VerbTestModel<Verb> initFullModel(bool hasMistake) {
  var model = VerbTestModel();
  model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive, 'fr',
      'translation', _mode, _tense);
  int i = 0;
  for (var element in _randomIndicative) {
    model.add(element, i++);
  }
  if (hasMistake) {
    //tamper with 3rd person singular
    model.add('wrong', 2);
  }
  return model;
}

Future<MaterialApp> createMaterialApp(SharedPreferences prefs) async {
  SettingsController controller =
      SettingsController(SettingsService(prefs), ThemeMode.dark, prefs);
  await controller.loadSettings();
  return MaterialApp(
    home: VerbIndicativeEvaluateRoute(controller),
  );
}

void testScore(int achievedScore, int maxScore) {
  Finder scoreFinder = find.text('$achievedScore/$maxScore');
  expect(scoreFinder, findsOneWidget);
}

void testTitle() {
  Finder titleFinderOne = find.text('Rapport');
  expect(titleFinderOne, findsOneWidget);
}

void testMetaDataCard() {
  Finder infinitiveFinder = find.text('werkwoord');
  expect(infinitiveFinder, findsOneWidget);
  Finder translationFinder = find.text('vertaling');
  expect(translationFinder, findsOneWidget);
  Finder modeFinder = find.text('modus');
  expect(modeFinder, findsOneWidget);
  Finder tenseFinder = find.text('tijd');
  expect(tenseFinder, findsOneWidget);
}
